@@ -13,6 +13,7 @@
 #' @importFrom Rcpp evalCpp
 #' @importFrom lbfgsb3c lbfgsb3c
 #' @importFrom rxode2 rxUiGet .malert .minfo .msuccess .mwarn
+#' @eval .nlmixr2estbuild()
 #' @import nlmixr2data
 #' @useDynLib nlmixr2est, .registration=TRUE
 
@@ -181,7 +182,7 @@ nlmixr <- nlmixr2
 .nlmixr2inferEst <- function(env, est) {
   if (!env$missingEst) {
     .cls <- class(est)
-    if (grepl("^.*?Control$", .cls)) {
+    if (length(.cls) == 1L && grepl("^.*?Control$", .cls)) {
       .est <- sub("^(.*?)Control$", "\\1", .cls)
       if (env$missingControl) {
         env$control <- getValidNlmixrControl(est, .est)
@@ -347,7 +348,7 @@ nlmixr2.nlmixr2FitCore <- function(object, data=NULL, est = NULL, control = NULL
   .modName <- deparse(substitute(object))
   nlmixr2global$nlmixr2SimInfo <- .simInfo(object)
   .cls <- class(est)
-  if (grepl("^.*?Control$", .cls)) {
+  if (length(.cls) == 1L && grepl("^.*?Control$", .cls)) {
     .est <- sub("^(.*?)Control$", "\\1", .cls)
     if (is.null(control)) {
       control <- getValidNlmixrControl(est, .est)
@@ -362,7 +363,7 @@ nlmixr2.nlmixr2FitCore <- function(object, data=NULL, est = NULL, control = NULL
     data <- NULL
   } else {
     .cls <- class(data)
-    if (grepl("^.*?Control$", .cls)) {
+    if (length(.cls) == 1L && grepl("^.*?Control$", .cls)) {
       .est <- sub("^(.*?)Control$", "\\1", .cls)
       if (is.null(control)) {
         control <- getValidNlmixrControl(data, .est)
