@@ -134,21 +134,6 @@ nmObjGetControl.focei <- function(x, ...) {
   stop("cannot find focei related control object", call.=FALSE)
 }
 
-#' @rdname nmObjGetControl
-#' @export
-nmObjGetControl.foce <- nmObjGetControl.focei
-
-#' @rdname nmObjGetControl
-#' @export
-nmObjGetControl.foi <- nmObjGetControl.focei
-
-#' @rdname nmObjGetControl
-#' @export
-nmObjGetControl.fo <- nmObjGetControl.focei
-
-#' @rdname nmObjGetControl
-#' @export
-nmObjGetControl.posthoc <- nmObjGetControl.focei
 
 #' @rdname nmObjGetControl
 #' @export
