@@ -561,7 +561,26 @@ addTable <- function(object, updateObject = FALSE,
     }
     .rownum <- as.integer(.df$nlmixrRowNums)
     assign(".rownum", .rownum, envir=.fit)
-    drop <- c(drop, "rxLambda", "rxYj", "nlmixrRowNums")
+    drop <- c(drop, "rxLambda", "rxYj", "nlmixrRowNums",
+              "rx__sens_central_BY_p1",
+                "rx__sens_central_BY_v1",
+                "rx__sens_central_BY_p2",
+                "rx__sens_central_BY_p3",
+                "rx__sens_central_BY_p4",
+                "rx__sens_central_BY_ka",
+                "rx__sens_peripheral1_BY_p1",
+                "rx__sens_peripheral1_BY_v1",
+                "rx__sens_peripheral1_BY_p2",
+                "rx__sens_peripheral1_BY_p3",
+                "rx__sens_peripheral1_BY_p4",
+                "rx__sens_peripheral1_BY_ka",
+                "rx__sens_peripheral2_BY_p1",
+                "rx__sens_peripheral2_BY_v1",
+                "rx__sens_peripheral2_BY_p2",
+                "rx__sens_peripheral2_BY_p3",
+                "rx__sens_peripheral2_BY_p4",
+                "rx__sens_peripheral2_BY_ka",
+                "rx__sens_depot_BY_ka")
     .w <- -which(names(.df) %in% drop)
     if (length(.w) > 0) .df <- .df[, .w, drop=FALSE]
     class(.df) <- "data.frame"
@@ -733,7 +752,7 @@ tableControl <- function(npde = NULL,
     censMethod=.censMethod,
     cholSEtol=cholSEtol, state=state, lhs=lhs, eta=eta, covariates=covariates, addDosing=addDosing, subsetNonmem=subsetNonmem, cores=cores, keep=keep, drop=drop)
   class(.ret) <- "tableControl"
-  return(.ret)
+  .ret
 }
 
 #' @export
