@@ -9,13 +9,7 @@
 #include "inner.h"
 
 
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext ("nlmixr2est", String)
-/* replace pkg as appropriate */
-#else
 #define _(String) (String)
-#endif
 
 #include "scale.h"
 
