@@ -43,9 +43,8 @@ nmTest({
     }
     dat <- qs::qread(test_path("test-resume-bobyqa.qs"))
 
-    d <- nlmixr2(model, dat, "focei")
+    d <- .nlmixr(model, dat, "focei")
 
     expect_true(grepl("bobyqa", d$extra))
-
   })
 })
